@@ -1,5 +1,5 @@
 """AMQP Messaging Framework for Python"""
-VERSION = (1, 1, 2)
+VERSION = (1, 1, 3)
 __version__ = ".".join(map(str, VERSION[0:3])) + "".join(VERSION[3:])
 __author__ = "Ask Solem"
 __contact__ = "ask@celeryproject.org"
@@ -14,7 +14,7 @@ if not os.environ.get("KOMBU_NO_EVAL", False):
     from types import ModuleType
 
     all_by_module = {
-            "kombu.connection": ["BrokerConnection"],
+            "kombu.connection": ["BrokerConnection", "Connection"],
             "kombu.entity": ["Exchange", "Queue"],
             "kombu.messaging": ["Consumer", "Producer"],
     }
