@@ -50,6 +50,17 @@ class MultiChannelPoller(object):
         # poll implementation (epoll/kqueue/select)
         self._poller = eventio.poll()
 
+    def close(self):
+        for fd in self._chan_to_sock.itervalues():
+            try:
+                self._poller.unregister(fd)
+            except KeyError:
+                pass
+        self._channels.clear()
+        self._fd_to_chan.clear()
+        self._chan_to_sock.clear()
+        self._poller = None
+
     def add(self, channel):
         self._channels.add(channel)
 
@@ -91,7 +102,8 @@ class MultiChannelPoller(object):
     def get(self, timeout=None):
         for channel in self._channels:
             if channel.active_queues:           # BRPOP mode?
-                self._register_BRPOP(channel)
+                if channel.qos.can_consume():
+                    self._register_BRPOP(channel)
             if channel.active_fanout_queues:    # LISTEN mode?
                 self._register_LISTEN(channel)
 
@@ -187,7 +199,7 @@ class Channel(virtual.Channel):
                         self._fanout_to_queue[payload["channel"]])
         raise Empty()
 
-    def _brpop_start(self, timeout=0):
+    def _brpop_start(self, timeout=1):
         queues = self.active_queues
         if not queues:
             return
@@ -208,8 +220,11 @@ class Channel(virtual.Channel):
                 dest__item = self.client.parse_response("BRPOP", **options)
             except self.connection.connection_errors:
                 raise Empty()
-            dest, item = dest__item
-            return deserialize(item), dest
+            if dest__item:
+                dest, item = dest__item
+                return deserialize(item), dest
+            else:
+                raise Empty()
         finally:
             self._in_poll = False
 
@@ -227,55 +242,55 @@ class Channel(virtual.Channel):
             Implies ``no_ack=True``
 
         """
-        item = self.client.rpop(queue)
+        item = self._avail_client.rpop(queue)
         if item:
             return deserialize(item)
         raise Empty()
 
     def _size(self, queue):
-        return self.client.llen(queue)
+        return self._avail_client.llen(queue)
 
     def _put(self, queue, message, **kwargs):
         """Deliver message."""
-        self.client.lpush(queue, serialize(message))
+        self._avail_client.lpush(queue, serialize(message))
 
     def _put_fanout(self, exchange, message, **kwargs):
         """Deliver fanout message."""
-        self.client.publish(exchange, serialize(message))
+        self._avail_client.publish(exchange, serialize(message))
 
     def _queue_bind(self, exchange, routing_key, pattern, queue):
         if self.typeof(exchange).type == "fanout":
             # Mark exchange as fanout.
             self._fanout_queues[queue] = exchange
-        self.client.sadd(self.keyprefix_queue % (exchange, ),
-                          self.sep.join([routing_key or "",
-                                        pattern or "",
-                                        queue or ""]))
+        self._avail_client.sadd(self.keyprefix_queue % (exchange, ),
+                            self.sep.join([routing_key or "",
+                                           pattern or "",
+                                           queue or ""]))
 
     def _has_queue(self, queue, **kwargs):
-        return self.client.exists(queue)
+        return self._avail_client.exists(queue)
 
     def get_table(self, exchange):
         return [tuple(val.split(self.sep))
-                    for val in self.client.smembers(
+                    for val in self._avail_client.smembers(
                             self.keyprefix_queue % exchange)]
 
     def _purge(self, queue):
-        size, _ = self.client.pipeline().llen(queue) \
+        size, _ = self._avail_client.pipeline().llen(queue) \
                                         .delete(queue).execute()
         return size
 
     def close(self):
-        # remove from channel poller.
-        self.connection.cycle.discard(self)
-
-        # Close connections
-        for attr in "client", "subclient":
-            try:
-                delattr(self, attr)
-            except (AttributeError, self.ResponseError):
-                pass
+        if not self.closed:
+            # remove from channel poller.
+            self.connection.cycle.discard(self)
 
+            # Close connections
+            for attr in "client", "subclient":
+                try:
+                    delattr(self, attr)
+                except (AttributeError, self.ResponseError):
+                    pass
         super(Channel, self).close()
 
     def _create_client(self):
@@ -305,6 +320,12 @@ class Channel(virtual.Channel):
         from redis import exceptions
         return exceptions.ResponseError
 
+    @property
+    def _avail_client(self):
+        if self._in_poll:
+            return self._create_client()
+        return self.client
+
     @cached_property
     def client(self):
         return self._create_client()
@@ -333,12 +354,11 @@ class Transport(virtual.Transport):
     interval = 1
     default_port = DEFAULT_PORT
     # poller is global for all Redis BrokerConnection's
-    default_cycle = MultiChannelPoller()
 
     def __init__(self, *args, **kwargs):
         super(Transport, self).__init__(*args, **kwargs)
         self.connection_errors, self.channel_errors = self._get_errors()
-        self.cycle = self.default_cycle
+        self.cycle = MultiChannelPoller()
 
     def _get_errors(self):
         from redis import exceptions
