@@ -245,3 +245,22 @@ try:
     from collections import OrderedDict
 except ImportError:
     OrderedDict = CompatOrderedDict
+
+############## queue.LifoQueue ##############################################
+from Queue import Queue
+
+
+class LifoQueue(Queue):
+
+    def _init(self, maxsize):
+        self.queue = []
+        self.maxsize = maxsize
+
+    def _qsize(self, len=len):
+        return len(self.queue)
+
+    def _put(self, item):
+        self.queue.append(item)
+
+    def _get(self):
+        return self.queue.pop()
